import os
import platform
from utils import is_juju_core

# Environment variables that can be used to configure
# what is tested.

# Series to install on deployed nodes.
NODE_SERIES = os.environ.get('NODE_SERIES', 'xenial')

# Whether or not the ARM nodes should be used
# in the test.
DO_NOT_USE_ARM_NODES = bool(
    os.environ.get('DO_NOT_USE_ARM_NODES', True))

USE_ARM_NODES = not DO_NOT_USE_ARM_NODES

CLUSTER_CONTROLLER_IP = '10.245.136.6'

SQUID_DEB_PROXY_URL = 'http://10.55.32.185:8000'
# HTTP proxy used to access the external world.
HTTP_PROXY = "http://162.213.35.104:3128"

# We cannot use the ARM nodes with juju-core because of
# bug 1227722.
#if is_juju_core():
#    USE_ARM_NODES = False

# Whether or not the juju tests should be performed.
DO_NOT_TEST_JUJU = bool(
    os.environ.get('DO_NOT_TEST_JUJU', True))

# Whether or not set the http proxy. Currently only working on raring
DO_NOT_SET_PROXY = bool("raring" not in platform.linux_distribution())

# Whether or not the cluster controller nodes in different network
# should be used.
USE_CC_NODES = bool(os.environ.get('USE_CC_NODES', False))

MAAS_URL = "http://10.245.136.6/MAAS"
USER_DATA_URL = "http://10.245.136.6/MAAS/metadata/enlist/latest/user-data"
ADMIN_USER = "admin"
PASSWORD = "test"
POWER_USER = "root"
POWER_PASS = "ubuntu"

REGION_CONTROLLER_NODES = {
    # lenovo-RD230-03, MAAS-03
    "00:E0:81:DD:D5:99": "10.245.143.103",
    # lenovo-RD230-04, MAAS-04
    "00:E0:81:DD:D1:0B": "10.245.143.104",
    # lenovo-RD230-05, MAAS-05
    #"00:E0:81:DD:D4:11": "10.245.143.105", # This machines seem busted. TODO: Investigate
    # lenovo-RD230-06, MAAS-06
    #"00:E0:81:D1:B1:47": "10.245.143.106", # This machine seems busted. TODO: Investigate
    # Took these two machines from the CLUSTER_CONTROLLER_NODES pool
    # as it seems that the other two were broken
    # lenovo-RD230-07, MAAS-07
    "00:E0:81:DD:D1:1B": "10.245.143.107",
    # lenovo-RD230-08, MAAS-08
    "00:E0:81:DD:D1:2B": "10.245.143.108",
}

CLUSTER_CONTROLLER_NODES = {
    # lenovo-RD230-09, MAAS-09
    "00:E0:81:DD:D1:A3": "10.245.143.109",
    # lenovo-RD230-10, MAAS-10
    "00:E0:81:DC:38:6D": "10.245.143.110",
    # lenovo-RD230-11, MAAS-11
    "00:E0:81:DD:D0:FF": "10.245.143.111",
    # lenovo-RD230-12, MAAS-12
    "00:E0:81:DD:D4:F9": "10.245.143.112"
}


LENOVO_LAB = REGION_CONTROLLER_NODES
if USE_CC_NODES:
    LENOVO_LAB.update(CLUSTER_CONTROLLER_NODES)

# TODO: mapping is outdated.
ARM_LAB = {
    'fc:2f:40:d8:fb:1a': '192.168.21.50',
    'fc:2f:40:fa:2f:9a': '192.168.21.51',
    'fc:2f:40:ec:73:42': '192.168.21.52',
    'fc:2f:40:d5:87:ce': '192.168.21.53'
}

# dnssec is now enabled by default, so disable it to avoid errors from the
# forwarder server.
# See StackOverflow question "ns got insecure response, parent indicates
# it should be secure": http://bit.ly/1pe8Hkk
LAB_DNS_CONFIG = """
options {
    directory "/var/cache/bind";
    forwarders {
    10.245.136.1;
    };
    allow-query-cache {any;};
    dnssec-enable no;
    dnssec-validation no;
    auth-nxdomain no;    # conform to RFC1035
};
"""

JUJU_CONFIG = """
default: maas
environments:
  maas:
    type: maas
    maas-server: '%s'
    maas-oauth: '%s'
    bootstrap-timeout: 18000
    admin-secret: 'nothing'
    default-series: %s
    logging-config: <root>=TRACE
    disable-network-management: true
"""
